@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *     
- *  This program was written by Adrian Mariano (adrian@cam.cornell.edu)
+ *  This program was written by Adrian Mariano (adrianm@gnu.org)
  */
 
 #include <math.h>
@@ -61,9 +61,6 @@ double strtod();
 #  define void int
 #endif
 
-#define NOPOINT 0
-#define POINT 1
-
 #define E_NORMAL 0
 #define E_PARSE 1
 #define E_PRODOVERFLOW 2
@@ -83,6 +80,7 @@ double strtod();
 #define E_FILE 16
 #define E_BADFILE 17
 #define E_MEMORY 18
+#define E_BADNUM 19
 
 #define WHITE " \t\n"
 
@@ -130,12 +128,17 @@ struct func {
   char *file;                  /* file where defined */ 
 };
 
+struct parseflag {
+  int oldstar;      /* Does '*' have higher precedence than '/' */
+  int minusminus;   /* Does '-' character give subtraction */
+};
+extern struct parseflag parserflags;
+
 extern struct unittype *parameter_value;
 extern char *function_parameter;
-extern int minusminus;
-extern int oldstar;
 
 void *mymalloc(int bytes,char *mesg);
+int hassubscript(const char *str, int length);
 void initializeunit(struct unittype *theunit);
 void freeunit(struct unittype *theunit);
 void unitcopy(struct unittype *dest, struct unittype *src);
@@ -150,6 +153,5 @@ char *dupstr(char *str);
 int unit2num(struct unittype *input);
 struct func *fnlookup(const char *str, int length);
 int evalfunc(struct unittype *theunit, struct func *infunc, int inverse);
-
 int parseunit(struct unittype *output, char *input,char **errstr,int *errloc);
 
